package HTML::FormFu::Element::_MultiSelect;

use strict;
use base 'HTML::FormFu::Element::_MultiElement',
    'HTML::FormFu::Element::Select';

1;

__END__

=head1 NAME

HTML::FormFu::Element::_MultiSelect

=head1 AUTHOR

Carl Franks, C<cfranks@cpan.org>

=head1 LICENSE

This library is free software, you can redistribute it and/or modify it under
the same terms as Perl itself.

=cut
